import { ShopperLogin } from 'commerce-sdk-isomorphic';
import { Argument, ExcludeTail } from '../types';
type Client = ShopperLogin<{
    shortCode: string;
}>;
type Params<T extends keyof QueryKeys> = Partial<Argument<Client[T]>['parameters']>;
export type QueryKeys = {
    getUserInfo: [
        '/commerce-sdk-react',
        '/organizations/',
        string | undefined,
        '/oauth2/userinfo',
        Params<'getUserInfo'>
    ];
    getWellknownOpenidConfiguration: [
        '/commerce-sdk-react',
        '/organizations/',
        string | undefined,
        '/oauth2/.well-known/openid-configuration',
        Params<'getWellknownOpenidConfiguration'>
    ];
    getJwksUri: [
        '/commerce-sdk-react',
        '/organizations/',
        string | undefined,
        '/oauth2/jwks',
        Params<'getJwksUri'>
    ];
};
type QueryKeyHelper<T extends keyof QueryKeys> = {
    /** Generates the path component of the query key for an endpoint. */
    path: (params: Params<T>) => ExcludeTail<QueryKeys[T]>;
    /** Generates the full query key for an endpoint. */
    queryKey: (params: Params<T>) => QueryKeys[T];
};
export declare const getUserInfo: QueryKeyHelper<'getUserInfo'>;
export declare const getWellknownOpenidConfiguration: QueryKeyHelper<'getWellknownOpenidConfiguration'>;
export declare const getJwksUri: QueryKeyHelper<'getJwksUri'>;
export {};
//# sourceMappingURL=queryKeyHelpers.d.ts.map